==> tuia-advert-center-api-2.0.1-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/material/AuditAdvertMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert.material;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: AuditAdvertMaterialDto <br/>
 * Function: 素材审核请求dto. <br/>
 * date: 2017年11月17日 上午11:22:19 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public class AuditAdvertMaterialDto implements Serializable {

    private static final long serialVersionUID = -4207247783618417671L;

    /** 审核类型：0-拒绝；3-通过 */
    private Integer           audiType;

    /** 素材Id */
    private Long              id;

    /** 拒绝理由 */
    private String            reason;

    /** 素材标签 */
    private List<String>      materialTagNums;

    /** 属性标签 */
    private List<String> advertBannedTagNums;

    /** 审核来源：0-兑吧；1-推啊 */
    private Integer           sourceAudit;

    private String auditor;

    /**
     * audiType.
     *
     * @return the audiType
     * @since JDK 1.8
     */
    public Integer getAudiType() {
        return audiType;
    }

    /**
     * audiType.
     *
     * @param audiType the audiType to set
     * @since JDK 1.8
     */
    public void setAudiType(Integer audiType) {
        this.audiType = audiType;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.8
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.8
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * reason.
     *
     * @return the reason
     * @since JDK 1.8
     */
    public String getReason() {
        return reason;
    }

    /**
     * reason.
     *
     * @param reason the reason to set
     * @since JDK 1.8
     */
    public void setReason(String reason) {
        this.reason = reason;
    }

    /**
     * materialTagNums.
     *
     * @return the materialTagNums
     * @since JDK 1.8
     */
    public List<String> getMaterialTagNums() {
        return materialTagNums;
    }

    /**
     * materialTagNums.
     *
     * @param materialTagNums the materialTagNums to set
     * @since JDK 1.8
     */
    public void setMaterialTagNums(List<String> materialTagNums) {
        this.materialTagNums = materialTagNums;
    }

    /**
     * sourceAudit.
     *
     * @return the sourceAudit
     * @since JDK 1.8
     */
    public Integer getSourceAudit() {
        return sourceAudit;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    /**
     * sourceAudit.
     *
     * @param sourceAudit the sourceAudit to set
     * @since JDK 1.8
     */
    public void setSourceAudit(Integer sourceAudit) {
        this.sourceAudit = sourceAudit;
    }

    public List<String> getAdvertBannedTagNums() {
        return advertBannedTagNums;
    }

    public void setAdvertBannedTagNums(List<String> advertBannedTagNums) {
        this.advertBannedTagNums = advertBannedTagNums;
    }
}

==> tuia-advert-center-api-2.0.6-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/material/AuditAdvertMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert.material;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: AuditAdvertMaterialDto <br/>
 * Function: 素材审核请求dto. <br/>
 * date: 2017年11月17日 上午11:22:19 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public class AuditAdvertMaterialDto implements Serializable {

    private static final long serialVersionUID = -4207247783618417671L;

    /** 审核类型：0-拒绝；3-通过 */
    private Integer           audiType;

    /** 素材Id */
    private Long              id;

    /** 拒绝理由 */
    private String            reason;

    /** 素材标签 */
    private List<String>      materialTagNums;

    /** 属性标签 */
    private List<String> advertBannedTagNums;

    /** 审核来源：0-兑吧；1-推啊 */
    private Integer           sourceAudit;

    private String auditor;

    /**
     * 审核人
     */
    private String reviewer;

    /**
     * audiType.
     *
     * @return the audiType
     * @since JDK 1.8
     */
    public Integer getAudiType() {
        return audiType;
    }

    /**
     * audiType.
     *
     * @param audiType the audiType to set
     * @since JDK 1.8
     */
    public void setAudiType(Integer audiType) {
        this.audiType = audiType;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.8
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.8
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * reason.
     *
     * @return the reason
     * @since JDK 1.8
     */
    public String getReason() {
        return reason;
    }

    /**
     * reason.
     *
     * @param reason the reason to set
     * @since JDK 1.8
     */
    public void setReason(String reason) {
        this.reason = reason;
    }

    /**
     * materialTagNums.
     *
     * @return the materialTagNums
     * @since JDK 1.8
     */
    public List<String> getMaterialTagNums() {
        return materialTagNums;
    }

    /**
     * materialTagNums.
     *
     * @param materialTagNums the materialTagNums to set
     * @since JDK 1.8
     */
    public void setMaterialTagNums(List<String> materialTagNums) {
        this.materialTagNums = materialTagNums;
    }

    /**
     * sourceAudit.
     *
     * @return the sourceAudit
     * @since JDK 1.8
     */
    public Integer getSourceAudit() {
        return sourceAudit;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    /**
     * sourceAudit.
     *
     * @param sourceAudit the sourceAudit to set
     * @since JDK 1.8
     */
    public void setSourceAudit(Integer sourceAudit) {
        this.sourceAudit = sourceAudit;
    }

    public List<String> getAdvertBannedTagNums() {
        return advertBannedTagNums;
    }

    public void setAdvertBannedTagNums(List<String> advertBannedTagNums) {
        this.advertBannedTagNums = advertBannedTagNums;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }
}
